"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ava_1 = require("ava");
const toggle_1 = require("./toggle");
(0, ava_1.default)('hidden does not render any button', async (t) => {
    const func = (0, toggle_1.generateToggleButton)('text', 'pre', {
        hide: () => true,
        isSet: () => {
            throw new Error('do not call as its hidden');
        },
        set: () => {
            throw new Error('do not call as its hidden');
        },
    });
    const button = await func(undefined, 'wow/');
    t.is(button, undefined);
});
(0, ava_1.default)('is true button', async (t) => {
    const func = (0, toggle_1.generateToggleButton)('text', 'pre', {
        isSet: () => true,
        set: () => {
            throw new Error('do not call as the button is not hit');
        },
    });
    const button = await func(undefined, 'wow/');
    t.deepEqual(button, {
        text: '✅ text',
        relativePath: 'pre:false',
    });
});
(0, ava_1.default)('is false button', async (t) => {
    const func = (0, toggle_1.generateToggleButton)('text', 'pre', {
        isSet: () => false,
        set: () => {
            throw new Error('do not call as the button is not hit');
        },
    });
    const button = await func(undefined, 'wow/');
    t.deepEqual(button, {
        text: '🚫 text',
        relativePath: 'pre:true',
    });
});
(0, ava_1.default)('own format', async (t) => {
    const func = (0, toggle_1.generateToggleButton)('text', 'pre', {
        isSet: () => true,
        set: () => {
            throw new Error('do not call as the button is not hit');
        },
        formatState: (_context, text, state) => {
            t.is(text, 'text');
            t.is(state, true);
            return 'lalala';
        },
    });
    const button = await func(undefined, 'wow/');
    t.deepEqual(button, {
        text: 'lalala',
        relativePath: 'pre:false',
    });
});
(0, ava_1.default)('async text', async (t) => {
    const func = (0, toggle_1.generateToggleButton)(() => 'text', 'pre', {
        isSet: () => true,
        set: () => {
            throw new Error('do not call as the button is not hit');
        },
    });
    const button = await func(undefined, 'wow/');
    t.deepEqual(button, {
        text: '✅ text',
        relativePath: 'pre:false',
    });
});
//# sourceMappingURL=toggle.test.js.map